@@ -1,9 +1,25 @@
 #!/usr/bin/env python
 
-"""A library that provides a Python interface to the Telegram Bots API"""
+"""
+    A library that provides a Python interface to the Telegram Bot API
+    Copyright (C) 2015 Leandro Toledo de Souza <leandrotoeldodesouza@gmail.com>
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU Lesser Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser Public License for more details.
+
+    You should have received a copy of the GNU Lesser Public License
+    along with this program.  If not, see [http://www.gnu.org/licenses/].
+"""
 
 __author__ = 'leandrotoledodesouza@gmail.com'
-__version__ = '2.5'
+__version__ = '2.5.1'
 
 from .base import TelegramObject
 from .user import User
